%define MAJver %(echo %version | cut -d. -f 1)
%define majorminor %(echo %version | cut -d. -f 1-2)

%define groupid  65010
%define userid   65010

Name:          squid
Version:       4.17
Release:       1mamba
Summary:       The Squid proxy caching server
Group:         System/Servers
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.squid-cache.org/
Source0:       http://www.squid-cache.org/Versions/v%{MAJver}/squid-%{version}.tar.xz
Source1:       %{name}-initscript
Source2:       %{name}-logrotate
Source3:       %{name}-pamd
Source4:       %{name}-sysconfig
Source5:       %{name}-conf
Source6:       %{name}.service
Patch:         %{name}-3.0.STABLE15-default_config.patch
Patch1:        %{name}-3.0.STABLE13-gcc44.patch
# patches from: http://www.squid-cache.org/Versions/v2/2.5/bugs/
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libbsd-devel
BuildRequires: libcap-devel
BuildRequires: libe2fs-devel
BuildRequires: libexpat-devel
BuildRequires: libgcc
BuildRequires: libgnutls-devel
BuildRequires: libkrb5-devel
BuildRequires: libltdl-devel
BuildRequires: libnetfilter_conntrack-devel
BuildRequires: libnettle-devel
BuildRequires: libnsl-devel
BuildRequires: libopenldap-devel
BuildRequires: libpam-devel
BuildRequires: libperl
BuildRequires: libsasl2-devel
BuildRequires: libstdc++6-devel
BuildRequires: libsystemd-devel
BuildRequires: libwww-devel
BuildRequires: libxml2-devel
BuildRequires: perl-Crypt-OpenSSL-X509
BuildRequires: perl-DBI
BuildRequires: perl-URI
BuildRequires: perl-devel
## AUTOBUILDREQ-END
BuildRequires: openjade
BuildRequires: linuxdoc-tools
Obsoletes:     squid-respawn
%systemd_requires

%description
Squid is a high-performance proxy caching server for Web clients, supporting FTP, gopher, and HTTP data objects.
Unlike traditional caching software, Squid handles all requests in a single, non-blocking, I/O-driven process.
Squid keeps meta data and especially hot objects cached in RAM, caches DNS lookups, supports non-blocking DNS lookups, and implements negative caching of failed requests.

Squid consists of a main server program squid, a Domain Name System lookup program (dnsserver), a program for retrieving FTP data (ftpget), and some management and client tools.

%debug_package

%prep
%setup -q -n %{name}-%{version}
#%patch -p1
#%patch1 -p1

find . -name \*.pl | xargs \
   sed -i "s,/usr/local/bin/perl,/usr/bin/perl,"

sed -i "s|-Werror||" configure

%build
%configure \
   --bindir=%{_sbindir} \
   --libexecdir=%{_libdir}/squid \
   --sysconfdir=%{_sysconfdir}/squid \
   --datadir=%{_datadir}/squid \
   --with-logdir=%{_localstatedir}/log/squid \
   --with-swapdir=%{_localstatedir}/spool/squid \
   --runstatedir=/run \
   --with-default-user=squid \
   --enable-delay-pools \
   --enable-snmp \
   --enable-ssl \
   --enable-linux-netfilter \
   --with-pthreads \
   --enable-cache-digests \
   --enable-cachemgr-hostname=hostname \
   --enable-digest-auth-helpers="password" \
   --enable-ntlm-auth-helpers="smb_lm,fakeauth" \
   --enable-basic-auth-helpers="LDAP,MSNT,NCSA,PAM,SMB,YP,getpwnam,multi-domain-NTLM,SASL,squid_radius_auth,POP3" \
   --enable-external-acl-helpers="file_userip,unix_group,wbinfo_group" \
   --enable-follow-x-forwarded-for \
   --enable-ident-lookups \
   --enable-removal-policies="heap,lru" \
   --enable-storeio="aufs,diskd,ufs,rock" \
   --enable-wccpv2 \
   --with-winbind-auth-challenge \
   --enable-icap-client \
   --disable-arch-native \
%ifnarch ia64 x86_64
   --with-large-files \
%endif
   --with-maxfd=8192

# LDAP_group: disabled, see https://bugs.squid-cache.org/show_bug.cgi?id=5042

# coss removed from --enable-storeio because:
# Error: COSS support is not stable in 3.0. Please do not use.

%make

# NOTE: sasl module compilation doesn't work but we don't really need it now
# INCLUDES="-I%{_includedir} -I%{_includedir}/sasl"

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall \
   bindir=%{_sbindir} \
   sysconfdir=%{_sysconfdir}/squid

install -D -m0644 %{SOURCE6} %{buildroot}%{_unitdir}/squid.service

#install -m755 -D %{S:1} %{buildroot}%{_initrddir}/squid
install -m644 -D %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/squid
install -m644 -D %{S:3} %{buildroot}%{_sysconfdir}/pam.d/squid
install -m644 -D %{S:4} %{buildroot}%{_sysconfdir}/sysconfig/squid
install -m640 -D %{buildroot}%{_sysconfdir}/squid/squid.conf.default %{buildroot}%{_sysconfdir}/squid/squid.conf

install -d %{buildroot}%{_var}/log/squid
install -d %{buildroot}%{_var}/spool/squid

# move squid mib to correct dir with correct name 
install -d %{buildroot}%{_datadir}/snmp/mibs
mv %{buildroot}%{_datadir}/squid/mib.txt \
   %{buildroot}%{_datadir}/snmp/mibs/SQUID-MIB.txt

# create void squid log files
> %{buildroot}/var/log/squid/access.log
> %{buildroot}/var/log/squid/cache.log
> %{buildroot}/var/log/squid/store.log

# remove unpackaged files
rm -f %{buildroot}%{_sbindir}/RunCache

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%pre
/usr/sbin/groupadd squid -g %{groupid} 2>/dev/null
/usr/sbin/useradd -u %{userid} -c 'Squid user' -d /dev/null -g squid \
   -s /bin/false squid 2>/dev/null
exit 0

%post
%systemd_post %{name}
:

%preun
%systemd_preun %{name}
# erase
if [ $1 -eq 0 ]; then
   /usr/sbin/userdel squid
fi
:

%postun
%systemd_postun_with_restart %{name}
:

%posttrans
# clean old sysv broken links
find /etc/rc[0-6].d/ -type l -xtype l -exec rm -f {} \;   
:

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/logrotate.d/squid
%config(noreplace) %{_sysconfdir}/pam.d/squid
%config(noreplace) %{_sysconfdir}/sysconfig/squid
%dir %{_sysconfdir}/squid
%config(noreplace) %attr(644,root,squid) %{_sysconfdir}/squid/cachemgr.conf
%config(noreplace) %{_sysconfdir}/squid/mime.conf
%config(noreplace) %attr(640,root,squid) %{_sysconfdir}/squid/squid.conf
#%config(noreplace) %{_sysconfdir}/squid/msntauth.conf
%config %{_sysconfdir}/squid/errorpage.css*
%{_sysconfdir}/squid/squid.conf.documented
%{_sysconfdir}/squid/*.conf.default
%{_sbindir}/purge
%{_sbindir}/squid
%{_sbindir}/squidclient
%{_unitdir}/squid.service
#%{_initrddir}/squid
%{_datadir}/squid/errors/*
%{_datadir}/squid/icons/*
%{_datadir}/snmp/mibs/SQUID-MIB.txt
%dir %{_libdir}/squid
%{_libdir}/squid/*.cgi
#%{_libdir}/squid/cert_valid.pl
%{_libdir}/squid/ext_file_userip_acl
#%{_libdir}/squid/ext_ldap_group_acl
%{_libdir}/squid/storeid_file_rewrite
%{_libdir}/squid/digest_edirectory_auth
%{_libdir}/squid/digest_file_auth
%{_libdir}/squid/digest_ldap_auth
%{_libdir}/squid/diskd
%{_libdir}/squid/basic_db_auth
%{_libdir}/squid/basic_fake_auth
%{_libdir}/squid/basic_getpwnam_auth
%{_libdir}/squid/basic_ldap_auth
#%{_libdir}/squid/basic_msnt_multi_domain_auth
%attr(4750,root,squid) %{_libdir}/squid/basic_ncsa_auth
#%{_libdir}/squid/basic_nis_auth
%attr(4750,root,squid) %{_libdir}/squid/basic_pam_auth
%{_libdir}/squid/basic_pop3_auth
%{_libdir}/squid/log_db_daemon
%{_libdir}/squid/basic_radius_auth
%{_libdir}/squid/basic_sasl_auth
%{_libdir}/squid/basic_smb_auth
%{_libdir}/squid/basic_smb_auth.sh
#%{_libdir}/squid/basic_smb_lm_auth
%{_libdir}/squid/ext_unix_group_acl
%{_libdir}/squid/ext_wbinfo_group_acl
%{_libdir}/squid/helper-mux
%{_libdir}/squid/log_file_daemon
%{_libdir}/squid/negotiate_kerberos_auth
%{_libdir}/squid/negotiate_kerberos_auth_test
%{_libdir}/squid/negotiate_wrapper_auth
%{_libdir}/squid/ntlm_fake_auth
#%{_libdir}/squid/ntlm_smb_lm_auth
%{_libdir}/squid/security_fake_certverify
%{_libdir}/squid/unlinkd
%{_libdir}/squid/url_fake_rewrite
%{_libdir}/squid/url_fake_rewrite.sh
%{_libdir}/squid/url_lfs_rewrite
%dir %attr(0755,squid,squid) %{_var}/log/squid
%ghost /var/log/squid/access.log
%ghost /var/log/squid/cache.log
%ghost /var/log/squid/store.log
%dir %attr(0755,squid,squid) %{_var}/spool/squid
%{_mandir}/man1/purge.1*
%{_mandir}/man1/squidclient.1*
%{_mandir}/man8/*
%doc CONTRIBUTORS COPYING CREDITS
#%doc ChangeLog
#%doc QUICKSTART README RELEASENOTES.html SPONSORS

%changelog
* Tue Oct 05 2021 Automatic Build System <autodist@mambasoft.it> 4.17-1mamba
- automatic version update by autodist

* Sat Jul 10 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 4.16-1mamba
- update to 4.16

* Tue May 11 2021 Automatic Build System <autodist@mambasoft.it> 4.15-1mamba
- automatic version update by autodist

* Tue Feb 23 2021 Automatic Build System <autodist@mambasoft.it> 4.14-1mamba
- automatic version update by autodist

* Sun Aug 23 2020 Automatic Build System <autodist@mambasoft.it> 4.13-1mamba
- automatic version update by autodist

* Sat Jun 13 2020 Automatic Build System <autodist@mambasoft.it> 4.12-1mamba
- automatic version update by autodist

* Wed Jan 22 2020 Automatic Build System <autodist@mambasoft.it> 4.10-1mamba
- automatic version update by autodist

* Wed Nov 06 2019 Automatic Build System <autodist@mambasoft.it> 4.9-1mamba
- automatic version update by autodist

* Fri Aug 02 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-1mamba
- update to 4.8

* Sat Aug 26 2017 Automatic Build System <autodist@mambasoft.it> 3.5.27-1mamba
- automatic version update by autodist

* Wed Aug 09 2017 Automatic Build System <autodist@mambasoft.it> 3.5.26-1mamba
- automatic version update by autodist

* Mon Jan 30 2017 Automatic Build System <autodist@mambasoft.it> 3.5.24-1mamba
- automatic version update by autodist

* Thu Dec 22 2016 Automatic Build System <autodist@mambasoft.it> 3.5.23-1mamba
- automatic version update by autodist

* Mon Oct 24 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.5.22-3mamba
- rebuilt wih --disable-arch-native to prevent segfault on cpus different from build one

* Sun Oct 23 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.5.22-2mamba
- systemd service support

* Mon Oct 10 2016 Automatic Build System <autodist@mambasoft.it> 3.5.22-1mamba
- automatic version update by autodist

* Fri Sep 09 2016 Automatic Build System <autodist@mambasoft.it> 3.5.21-1mamba
- automatic version update by autodist

* Sat Jul 02 2016 Automatic Build System <autodist@mambasoft.it> 3.5.20-1mamba
- automatic version update by autodist

* Mon May 09 2016 Automatic Build System <autodist@mambasoft.it> 3.5.19-1mamba
- automatic version update by autodist

* Sat May 07 2016 Automatic Build System <autodist@mambasoft.it> 3.5.18-1mamba
- automatic version update by autodist

* Thu Apr 21 2016 Automatic Build System <autodist@mambasoft.it> 3.5.17-1mamba
- automatic version update by autodist

* Sat Apr 02 2016 Automatic Build System <autodist@mambasoft.it> 3.5.16-1mamba
- automatic version update by autodist

* Wed Feb 24 2016 Automatic Build System <autodist@mambasoft.it> 3.5.15-1mamba
- automatic version update by autodist

* Tue Feb 16 2016 Automatic Build System <autodist@mambasoft.it> 3.5.14-1mamba
- automatic version update by autodist

* Thu Jan 07 2016 Automatic Build System <autodist@mambasoft.it> 3.5.13-1mamba
- automatic version update by autodist

* Thu Dec 03 2015 Automatic Build System <autodist@mambasoft.it> 3.5.12-1mamba
- automatic version update by autodist

* Sun Jan 18 2015 Automatic Build System <autodist@mambasoft.it> 3.5.1-1mamba
- automatic version update by autodist

* Thu Dec 11 2014 Automatic Build System <autodist@mambasoft.it> 3.4.10-1mamba
- automatic version update by autodist

* Thu Nov 06 2014 Automatic Build System <autodist@mambasoft.it> 3.4.9-1mamba
- automatic version update by autodist

* Sun Oct 26 2014 Automatic Build System <autodist@mambasoft.it> 3.4.8-1mamba
- automatic version update by autodist

* Tue Dec 03 2013 Automatic Build System <autodist@mambasoft.it> 3.3.11-1mamba
- automatic version update by autodist

* Mon Nov 04 2013 Automatic Build System <autodist@mambasoft.it> 3.3.10-1mamba
- automatic version update by autodist

* Fri Sep 13 2013 Automatic Build System <autodist@mambasoft.it> 3.3.9-1mamba
- automatic version update by autodist

* Sun Jul 14 2013 Automatic Build System <autodist@mambasoft.it> 3.3.8-1mamba
- automatic version update by autodist

* Thu Jul 11 2013 Automatic Build System <autodist@mambasoft.it> 3.3.7-1mamba
- automatic version update by autodist

* Mon Jul 01 2013 Automatic Build System <autodist@mambasoft.it> 3.3.6-1mamba
- automatic version update by autodist

* Tue May 21 2013 Automatic Build System <autodist@mambasoft.it> 3.3.5-1mamba
- automatic version update by autodist

* Sat Apr 27 2013 Automatic Build System <autodist@mambasoft.it> 3.3.4-1mamba
- automatic version update by autodist

* Wed Mar 13 2013 Automatic Build System <autodist@mambasoft.it> 3.3.3-1mamba
- automatic version update by autodist

* Sat Mar 02 2013 Automatic Build System <autodist@mambasoft.it> 3.3.2-1mamba
- automatic version update by autodist

* Mon Feb 18 2013 Automatic Build System <autodist@mambasoft.it> 3.3.1-1mamba
- automatic version update by autodist

* Fri Jan 11 2013 Automatic Build System <autodist@mambasoft.it> 3.3.0.3-1mamba
- automatic version update by autodist

* Mon Nov 19 2012 Automatic Build System <autodist@mambasoft.it> 3.3.0.1-1mamba
- automatic version update by autodist

* Sun Oct 21 2012 Automatic Build System <autodist@mambasoft.it> 3.2.3-1mamba
- automatic version update by autodist

* Mon Oct 08 2012 Automatic Build System <autodist@mambasoft.it> 3.2.2-1mamba
- automatic version update by autodist

* Fri Sep 21 2012 Automatic Build System <autodist@mambasoft.it> 3.2.1-1mamba
- automatic update by autodist

* Sat Jun 09 2012 Automatic Build System <autodist@mambasoft.it> 3.1.20-1mamba
- automatic version update by autodist

* Mon Feb 06 2012 Automatic Build System <autodist@mambasoft.it> 3.1.19-1mamba
- automatic version update by autodist

* Fri Oct 14 2011 Automatic Build System <autodist@mambasoft.it> 3.1.16-1mamba
- automatic version update by autodist

* Sun Aug 28 2011 Automatic Build System <autodist@mambasoft.it> 3.1.15-1mamba
- automatic version update by autodist

* Mon Jul 04 2011 Automatic Build System <autodist@mambasoft.it> 3.1.14-1mamba
- automatic update by autodist

* Mon Jul 04 2011 Automatic Build System <autodist@mambasoft.it> 3.1.13-1mamba
- automatic update by autodist

* Tue May 31 2011 Automatic Build System <autodist@mambasoft.it> 3.1.12.2-1mamba
- automatic update by autodist

* Fri Apr 29 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.12-3mamba
- set datadir to %_datadir/squid
- set default cache_dir size to 384 MB to remove a warning about cache_mem default of 256 MB

* Wed Apr 27 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.12-2mamba
- rebuilt with --enable-icap-client

* Mon Apr 04 2011 Automatic Build System <autodist@mambasoft.it> 3.1.12-1mamba
- automatic update by autodist

* Thu Mar 24 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.11-2mamba
- sysconfig/squid: remove obsolete -D option

* Fri Mar 04 2011 Automatic Build System <autodist@mambasoft.it> 3.1.11-1mamba
- automatic update by autodist

* Sun Jan 30 2011 Automatic Build System <autodist@mambasoft.it> 3.1.10-1mamba
- automatic update by autodist

* Tue Nov 02 2010 Automatic Build System <autodist@mambasoft.it> 3.1.9-1mamba
- automatic update to 3.1.9 by autodist

* Wed Sep 08 2010 Automatic Build System <autodist@mambasoft.it> 3.1.8-1mamba
- automatic update to 3.1.8 by autodist

* Wed Aug 25 2010 Automatic Build System <autodist@mambasoft.it> 3.1.7-1mamba
- automatic update to 3.1.7 by autodist

* Wed Aug 04 2010 Automatic Build System <autodist@mambasoft.it> 3.1.6-1mamba
- automatic update to 3.1.6 by autodist

* Mon Jun 28 2010 Automatic Build System <autodist@mambasoft.it> 3.1.4-1mamba
- automatic update by autodist

* Fri Jun 04 2010 Automatic Build System <autodist@mambasoft.it> 3.1.3-1mamba
- automatic update to 3.1.3 by autodist

* Wed Dec 23 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE21-1mamba
- automatic update by autodist

* Thu Nov 19 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE20-1mamba
- automatic update by autodist

* Thu Oct 01 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE19-1mamba
- automatic update by autodist

* Fri Aug 07 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE18-1mamba
- automatic update by autodist

* Fri Jul 31 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE17-1mamba
- automatic update by autodist

* Wed Jul 22 2009 Automatic Build System <autodist@mambasoft.it> 3.0.STABLE16-1mamba
- automatic update by autodist

* Thu Apr 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE14-1mamba
- automatic update by autodist

* Mon Mar 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE13-1mamba
- automatic update by autodist

* Sun Jan 04 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE11-1mamba
- automatic update by autodist

* Mon Dec 22 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE9-1mamba
- update to 3.0.STABLE9

* Mon Sep 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE8-1mamba
- automatic update to 3.0.STABLE8 by autodist

* Tue Jun 17 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.STABLE6-1mamba
- update to 3.0.STABLE6

* Wed Sep 05 2007 Aleph0 <aleph0@openmamba.org> 2.6.STABLE15-1mamba
- update to 2.6.STABLE15

* Mon Jul 16 2007 Aleph0 <aleph0@openmamba.org> 2.6.STABLE14-1mamba
- update to 2.6.STABLE14

* Tue May 15 2007 Aleph0 <aleph0@openmamba.org> 2.6.STABLE13-1mamba
- update to 2.6.STABLE13
- initscript: remove lock file when stopping squid

* Thu Apr 12 2007 Aleph0 <aleph0@openmamba.org> 2.6.STABLE12-1mamba
- update to version 2.6.STABLE12 by autospec
- moved all binary files to %{_sbindir}
- changed file mode setting for squid.conf (640,root,squid)
- removed package squid-respawn
- new initscript

* Mon May 22 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE14-1qilnx
- update to version 2.5.STABLE14 by autospec

* Thu Mar 16 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE13-1qilnx
- update to version 2.5.STABLE13 by autospec

* Thu Oct 27 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE12-1qilnx
- update to version 2.5.STABLE12 by autospec
- security patches removed (merged upstream)

* Mon Oct 24 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE11-3qilnx
- security fix QSA-2005-126 (CAN-2005-3258)

* Mon Oct 03 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE11-2qilnx
- official patch: delaypools_truncated

* Mon Sep 26 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE11-1qilnx
- update to version 2.5.STABLE11 by autospec
- security patches removed (merged upstream)

* Fri Sep 16 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE10-4qilnx
- store_pending patch: security fix QSA-2005-106 (CAN-2005-2794)

* Thu Sep 08 2005 Alessandro Ramazzina <alessandro.ramazzina@qilinux.it> 2.5.STABLE10-3qilnx
- security fix: QSA-2005-104

* Wed Jun 22 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE10-2qilnx
- rebuilt with support for 4096 file descriptors (see http://www.llg.it/Squid-Book/HTML/sec-file-descriptor.html)

* Mon May 30 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE10-1qilnx
- update to version 2.5.STABLE10 by autospec
- make logfiles %%ghost files
- added %%post scriptlet using code from QiLinux installation scripts
- removed security pathes (merged upstream)

* Tue May 10 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE9-3qilnx
- security fix: QSA-2005-064 (CAN-2005-1345)

* Wed Mar 09 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE9-2qilnx
- fixed a minor security issue: CAN-2005-0626

* Tue Mar 08 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE9-1qilnx
- update to version 2.5.STABLE9 by autospec

* Mon Feb 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE8-1qilnx
- update to version 2.5.STABLE8 by autospec
- security fix: QSA-2005-018 (CAN-2005-0446)

* Tue Feb 15 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE7-8qilnx
- security fix QSA-2005-016 (CAN-2005-0174, CAN-2005-0211, CAN-2005-0241)

* Mon Jan 31 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE7-7qilnx
- squid mib file renamed to SQUID-MIB.txt

* Mon Jan 24 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE7-6qilnx
- security fix QSA-2005-006 (CAN-2005-00[94,95,96,97], CAN-2005-017[3,5])

* Fri Jan 21 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE7-5qilnx
- mib.txt moved to default mibs dir

* Fri Jan 21 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE7-4qilnx
- rebuilt with --enable-snmp option

* Fri Dec 17 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE7-3qilnx
- fixed minor security issues QSA-2004-066

* Mon Oct 18 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.STABLE7-2qilnx
- specfile fixes

* Fri Oct 15 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE7-1qilnx
- update to version 2.5.STABLE7 by autospec
- also fixed security flaws (QSA-2004-038): CAN-2004-0[541,832,918]

* Mon Apr 05 2004 Davide Madrisan <davide.madrisan@qilinuc.it> 2.5.STABLE5-1qilnx
- rebuilt with squid-2.5.STABLE5 (also fixes the security flaw CAN-2004-0189)

* Tue Nov 25 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.STABLE4-2qilnx
- changed user from nobody to squid
- added daemontools support for respawn
- fixed initscript restart
- added /etc/sysconfig/squid 

* Thu Oct 23 2003 Davide Madrisan <davide.madrisan@qilinuc.it> 2.5.STABLE4-1qilnx
- new policies for chkconfig and automatic start/restart of the squid service
- rebuilt with latest stable version

* Fri Jun 27 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-9qilnx
- fixed pam accounting problem (used pam_permit as accounting module)

* Fri Jun 20 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-8qilnx
- added correct post and postun scripts

* Wed Jun 04 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-7qilnx
- suid-ed pam_auth module (because it needs root privileges

* Tue Jun 03 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-6qilnx
- added authentication modules configuration

* Wed May 21 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-5qilnx
- moved user and group creation from %post to %pre script

* Mon May 19 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-4qilnx
- changed logdir and cachedir position and permissions
- added group creation

* Fri May 16 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.5-3qilnx
- added correct sysconfdir in configure

* Fri May 16 2003 Alessandro Ramazzina <alessandro.ramazzina@qinet.it> 2.5-2qilnx
- Added the right permissions to the init script

* Fri May 16 2003 Alessandro Ramazzina <alessandro.ramazzina@qinet.it> 2.5-1qilnx
- creation of squid package
